# Thetadata Python API

The [Thetadata](https://thetadata.net) Python API provides low latency US equities & options data that may be used for
market research or algorithmic trading applications.

Please see this repository's [documentation](https://thetadata-api.github.io/thetadata-python) for more details.

## Installation

Java 11 or higher is required. If you are on Windows, Java 19 will automatically be installed for you.

`pip install thetadata`

Please see our [official installation instructions](https://thetadata-api.github.io/thetadata-python/tutorials/#installation)
to get started.

## Contributing

We welcome all feedback, whether it comes in the form of Github issues, pull requests, or pings in our [Discord](discord.thetadata.us)!
